# Seagnal

_Approximating GUI reward functions with VLMs_

See [this](https://docs.google.com/document/d/1f3bNNbzKU-CfB-PuOsH__XJL9IYyxVdceXncG2jVk0U/edit?usp=sharing).

## Installation

`flash-attn` requires torch so one way to install would be:

```
uv sync --no-install-package flash-attn
uv sync
```